==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/LOADFACTORRANGE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour LOADFACTORRANGE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LOADFACTORRANGE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWRANGE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHRANGE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESIGNCONSUMPTIONRATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOADFACTORRANGE_Type", propOrder = {
    "lowrange",
    "highrange",
    "designconsumptionrate"
})
public class LOADFACTORRANGE_Type {

    @XmlElement(name = "LOWRANGE")
    protected long lowrange;
    @XmlElement(name = "HIGHRANGE")
    protected long highrange;
    @XmlElement(name = "DESIGNCONSUMPTIONRATE", required = true)
    protected QUANTITY designconsumptionrate;

    /**
     * Obtient la valeur de la propriété lowrange.
     * 
     */
    public long getLOWRANGE() {
        return lowrange;
    }

    /**
     * Définit la valeur de la propriété lowrange.
     * 
     */
    public void setLOWRANGE(long value) {
        this.lowrange = value;
    }

    /**
     * Obtient la valeur de la propriété highrange.
     * 
     */
    public long getHIGHRANGE() {
        return highrange;
    }

    /**
     * Définit la valeur de la propriété highrange.
     * 
     */
    public void setHIGHRANGE(long value) {
        this.highrange = value;
    }

    /**
     * Obtient la valeur de la propriété designconsumptionrate.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDESIGNCONSUMPTIONRATE() {
        return designconsumptionrate;
    }

    /**
     * Définit la valeur de la propriété designconsumptionrate.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDESIGNCONSUMPTIONRATE(QUANTITY value) {
        this.designconsumptionrate = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/LOADFACTORRANGE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for LOADFACTORRANGE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LOADFACTORRANGE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOWRANGE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HIGHRANGE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESIGNCONSUMPTIONRATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LOADFACTORRANGE_Type", propOrder = {
    "lowrange",
    "highrange",
    "designconsumptionrate"
})
public class LOADFACTORRANGE_Type {

    @XmlElement(name = "LOWRANGE")
    protected long lowrange;
    @XmlElement(name = "HIGHRANGE")
    protected long highrange;
    @XmlElement(name = "DESIGNCONSUMPTIONRATE", required = true)
    protected QUANTITY designconsumptionrate;

    /**
     * Gets the value of the lowrange property.
     * 
     */
    public long getLOWRANGE() {
        return lowrange;
    }

    /**
     * Sets the value of the lowrange property.
     * 
     */
    public void setLOWRANGE(long value) {
        this.lowrange = value;
    }

    /**
     * Gets the value of the highrange property.
     * 
     */
    public long getHIGHRANGE() {
        return highrange;
    }

    /**
     * Sets the value of the highrange property.
     * 
     */
    public void setHIGHRANGE(long value) {
        this.highrange = value;
    }

    /**
     * Gets the value of the designconsumptionrate property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDESIGNCONSUMPTIONRATE() {
        return designconsumptionrate;
    }

    /**
     * Sets the value of the designconsumptionrate property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDESIGNCONSUMPTIONRATE(QUANTITY value) {
        this.designconsumptionrate = value;
    }

}
